<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar" sourcelanguage="fr">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>النقر للعودة الى التطبيق </translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>التنزيلات</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>تنظيف</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 عنصر</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>المحاولة مرة أخرى</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>توقف</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>نشر البودكاست على يوتيوب</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>العنوان</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>الناشر</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>لوحة</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>الويب</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>وثائق</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>قلم الراسمة</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>الخلفيات</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>تغيير الخلفية</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation> إعادة</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>الصفحة السابقة</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>الصفحة التالية</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>إدارة الوثائق</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>تصفح مواقع الإنترنت</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>سطر</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>سطر صغير</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>سطر متوسط</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>سطر كبير</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>مغادرة</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>ممحاة</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">ممحاة صغيرة</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>ممحاة متوسطة </translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>ممحاة كبيرة</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">لون</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>العودة</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>أمام</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين </translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>تحديث الصفحة الحالية</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>الصفحة البدء</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>تحديث الصفحة البدء</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>اشارات مرجعية</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>اظهار الاشارات المرجعية</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>اشارة مرجعية</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>اضافة اشارة مرجعية</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>عرض اللوحة</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>مسح</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>مسح المحتوى</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>تفضيلات</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>عرض التفضيلات </translation>
    </message>
    <message>
        <source>Library</source>
        <translation>المكتبة</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>اظهار المكتبة</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>اظهار سطح المكتب</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>اظهار سطح مكتب الحاسوب</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>حجم أكبر</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>تكبير</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>حجم أصغر</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>تصغير</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>مجلد جديد</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>انشاء مجلد جديد</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>وثيقة جديدة</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>انشاء وثيقة جديدة</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>استيراد</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>استيراد وثيقة</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>تصدير وثيقة</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>الفتح في اللوحة</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>فتح الصفحة في اللوحة</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>تكرار</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>تكرار المحتوى المحدد</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>حذف المحتوى المحدد</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>اضافة الى وثيقة العمل</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>اضافة المحتوى المحدد الى الوثيقة المفتوحة </translation>
    </message>
    <message>
        <source>Add</source>
        <translation>اضافة</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>اضافة المحتوى الى الوثيقة</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>إعادة تسمية المحتوى</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>أدوات</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>عرض الأدوات</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>شاشات متعددة</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>حجم كبير (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>استعمال الوثيقة في حجم كبير (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>حجم عادي (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>استعمال الوثيقة في حجم عادي(4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>حجم مخصص</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>استعمال حجم الوثيقة المخصص</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>توقيف التحميل</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>توقيف تحميل صفحة الويب</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>قص</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>الصاق</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>سكون</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>وضع التقديم في وضع السكون</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>لوحة مفاتيح افتراضية</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>عرض مفاتيح افتراضية</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>خلفية بضوء عادي</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>ضوء</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>خلفية بضوء شبكي</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>خلفية داكنة عادية</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>داكن</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>خلفية داكنة شبكية</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>بودكاست</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>تسجيل التقديم بالفيديو</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>بدء تسجيل الشاشة</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>فسخ العناصر</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>فسخ كل العناصر</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>فسخ الملاحظات</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>فسخ كل الملاحظات</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>مسح الصفحة</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>مسح كل المكونات</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>تعليم الوثيقة</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>فسخ الملاحظة</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>علامة</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>تمييز </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>أداء انتقاء </translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>انتقاء وتغيير أشياء</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>يد</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>الانتقال ضمن الصفحة</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>مؤشر ليزر</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>مؤشر ليزر افتراضي</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>رسم خطوط</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>كتابة نص</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>التقاط</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>التقاط جزء من الشاشة</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>الاضافة الى الصفحة الحالية </translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>اضافة العنصر الى الصفحة الحالية </translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>الاضافة الى الصفحة الجديدة</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>اضافة العنصر الى الصفحة الجديدة</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>الاضافة الى المكتبة</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>اضافة العنصر الى المكتبة</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>صفحات</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>انشاء صفحة جديدة</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>صفحة جديدة</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>تكرار صفحة</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>تكرار الصفحة الحالية</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>استيراد صفحة</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>استيراد صفحة خارجية</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفة قصيرة</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>ايقاف تسجيل البودكاست مؤقتا</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>تكوين البودكاست</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>ضبط تسجيل البودكاست</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">قلاش تراب</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">محتوى فلاش تراب</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>ويب تراب</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>محتوى ويب تراب</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>التقاط مخصص</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>التقاط نافذة</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>التقاط نافذة</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>تضمين محتوى ويب</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>التقاط محتوى ويب قابل للتضمين</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>اظهار العرض</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>اظهار الشاشة الرئيسية على شاشة العرض</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>فسخ كل الملاحظات</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>استيراد محاكاة eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>البحث عن تحديث</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>مغادرة فتح Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>إخفاء فتح Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>إخفاء تطبيق فتح Sankoré</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>التفاعل مع العناصر</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>فسخ الخلفية</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>إزالة الخلفية</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>مطلوب مصادقة</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>اسم المتخدم:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>كلمة السر:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>مصادقة بروكسي</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>الاتصال ببروكسي</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>اسم المتخدم:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>كلمة السر:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>تسجيل اسم المستخدم وكلمة السر للاستعمالات المقبلة</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>معرّف المكوّن =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>المحتوى غير مدعوم في النسق الهدف.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>ازالة الصفحة</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>هل تريدون حقا إزالة صفحة واحدة من الوثيقة &apos;%0&apos; المختارة؟</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>حجم الصفحة</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>بودكاست</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>الويب</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>تحديث جديد متوفر، هل تريدون الذهاب الى صفحة الويب؟</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>ليس هناك تحديثات</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>تحديث متوفّر</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>التحيين</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>فشل تنزيل المحتوى 1%</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>انتهاء التنزيل</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>نوع أداة مجهول 1%</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>نوع محتوى مجهول 1%</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>اضافة عنصر</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>دعم الجميع (1%)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">إزالة صفحة%1  من الوثيقة</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>تمت إزالة صفحة%1  </translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>فشلت عملية إضافة الملف: خطأ في نسخ الملف</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>تجميع</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>تفريق</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">لون</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>خطأ عند اضافة الصورة الى المكتبة</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>صورة ملتقطة</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>خصائص التخزين المؤقت</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>اللون:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>الشكل:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>الحجم:</translation>
    </message>
    <message>
        <source>Close</source>
        <translatorcomment>اغلاق:</translatorcomment>
        <translation>Close</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>التقاط جزء من الشاشة</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>التقاط الشاشة</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>اظهار لوحة قلم الراسمة</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>اظهار اللوحة على الشاشة الثانوية</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>اظهار سطح المكتب على الشاشة الثانوية</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>مجلد جديد</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>صفحة 1%</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>اضافة مجلد صور</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>اضافة صور</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>اضافة صفخات من ملف</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>تكرار الوثيقة 1%</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>وقع نسخ الوثيقة 1%</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">ازالة الصفحة</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">ازالة الوثيقة</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">هل تريدون حقا ازالة الوثيقة &apos;1%&apos;؟</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">إفراغ سلة المهملات</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">هل تريدون حقا إفراغ سلة المهملات؟</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">يجري افراغ سلة المهملات</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">تمّ افراغ سلة المهملات</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">ازالة مجلد</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">هل تريدون حقا ازالة المجلد &apos;1%&apos; وكل محتوياته؟</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">لم يقع اختيار وثيقة!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>فتح الملف المدعوم</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>استيراد ملف 1%...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>فشل في استيراد الملف... </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>استيراد كل الصور من المجلد</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>افراغ</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>سلة المهملات</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>فتح وثيقة</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>اضافة كل الصور الى الوثيقة</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>كل الصور (1%)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>الاختيار لا يحتوي على ملفات صور!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>هل تريدون حقّا إزالة %n صفحة من الوثيقة المختارة &apos;%1&apos; ؟</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>المجلد لا يحتوي على ملفات صور</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>وثائق غير معنونة</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>فيديو</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>أشياء</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>نماذج مصغرة</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>كل الملفات المدعومة (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>حفظ الملف 1%</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>إدراج صفحة %1 من أصل %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>استيراد ناجح.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>نجح استيراد الملف %1</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>استيراد ملف 1%</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>صفحة %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">فشل التصدير.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">موافقة</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">إلغاء </translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">سلة المهملات</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 صفحة منسوخة</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 صفحة منسوخة</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">نسخ الصفحة 1% / 2%</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">1 % (نسخ)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">نسخ الصفحة 1% / 2%</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 صفحة منسوخة</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>تحميل الملفات</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء </translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">صفحة %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">صفحة %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>ظهر تحذير أثناء التصدير</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">تصدير ناجح.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>التصدير للـIWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>التصدير كملف IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>تصدير ناجح.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>فشل التصدير.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>صفحة</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>التصدير كملف UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">تصدير ناجح.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>تصدير 1% 2% من 3%</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">تصدير ناجح.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">فشل التصدير.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>التصدير كملف PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">تصدير ناجح.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>التصدير للـPDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>التصدير كملف PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">تصدير ناجح.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>تصدير الصفحة 1% من 2%</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>التصدير للـPDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>صفحة</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>التصدير كبيانات ويب</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>تصدير الوثيقة...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>تصدير ناجح.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>فشل التصدير.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>التصدير لمتصفح الويب</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>الاضافة الى الصفحة</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">تعيين كخلفية</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>الاضافة الى المكتبة</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>معلومات حول الأشياء</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>الاضافة الى المفضلة</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>تقاسم</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>العودة الى المجلد</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>الحذف من المفضلة</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>انشاء مجلد جديد</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>إعادة مسح نظام الملفات</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>الصورة المستوردة</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>ملفات صوتية</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>أفلام</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">حركات</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>تفاعلات</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>تطبيقات</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>أشكال</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>مفضلة</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>بحث على الويب</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>سلة المهملات</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>موافقة</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء </translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>إدخال اسم مجلد جديد</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>تحميل</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>مقفل</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>مرئي على الشاشة الكبيرة</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>مقفل</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>مرئي على الشاشة الكبيرة</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>الذهاب الى مصدر المحتوى</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">تعيين كخلفية</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Type Text Here&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>لون النص</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>قابل للنشر</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>الويب</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>تحميل...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>مجمد</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>التحويل كأداة </translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>شكل ملف مشترك (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>استيراد ملف 1%...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>فشل تصدير الملف 1%</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>استيراد ناجح</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>استيراد فاشل.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>استيراد ملف 1%...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>استيراد ناجح</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>فشل تصدير الملف 1%</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>شكل الصورة (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>فشل استيراد PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>استيراد الصفحة 1% من 2%</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>خطأ عند نشر الفيديو على الشبكة الداخلية (1%)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>يجري النشر على الشبكة الداخلية %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>نشر</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>دخول</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <source>No</source>
        <translation>لا</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>موافق</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>غلق</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>فشل الاتصال ببروكسي</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>أخطاء SSL: %1 %2 هل تريدون تجاهل هذه الأخطاء بالنسبة لهذا المضيف؟</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;إدخال اسم مستعمل وكلمة مرور لـ &quot;%1&quot; في %2  &lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <source>No</source>
        <translation>لا</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">إلغاء </translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(نسخ)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>خسارة سجل الوثيقة</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>انجليزي</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>روسي</translation>
    </message>
    <message>
        <source>German</source>
        <translation>ألماني</translation>
    </message>
    <message>
        <source>French</source>
        <translation>فرنسي</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>فرنسي سويسري</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>فشل بدء التشفير...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>لا يوجد مشفر بودكاست...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>جزء 1%</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>على سطح مكتبكم</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>في المجلد 1%</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>انشاء البودكاست 1%</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>خطأ تسجيل البودكاست (1%)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>مدخل الصوت الافتراضي</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>لا توجد تسجيلات صوتية</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>صغير</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>متوسط</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>كامل</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>النشر على الشبكة الداخلية</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>النشر على اليوتوب</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>نسخة: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>العلامة حساسة للضغط</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">دخول بروكسي</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">اسم المتخدم:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">كلمة السر:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">نشر الوثيقة على الويب</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">العنوان:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">الوصف:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">نشر</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>أفلامي</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>توليد صور معاينة مصغرة...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>1 % صور مصغرة مولّدة</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">صفحة %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>قناع</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>مسطرة</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>بوصلة</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>منقلة</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>مثلث</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>مكبرة</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>تخزين مؤقت</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>صفحة كاملة</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>الويب</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>محدّث الوثيقة</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> تحتاج الملفات الى تحديث.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>مسار النسخ الاحتياطي:  </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>تصفح</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>التحيين</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>اختيار مجلد النسخ الاحتياطي</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>حدث خطأ أثناء التحديث. لم يقع التأثير على الملفات.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>نتائج تحديث الملفات</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>تحديث الملف </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>يرجى الانتظار، ستبدأ عملية الاستيراد عن قريب...</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>نجاح تحديث الملفات!
يرجى إعادة تشغيل التطبيق للوصول إلى الوثائق المحدثة.
</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>التذكير لاحقا</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>تحميل...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 called (method=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>فشلت المصادقة في اليوتوب</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>خطأ عند تحميل الفيديو على اليوتوب (1%)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>يجري التحميل على الشبكة اليوتوب %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>التحميل</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>موسيقى</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>رياضة</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>لعب فيديو</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>كوميديا</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>ترفيه</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>تعليم</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>سيارات وعربات</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>حيوانات وحيوانات أليفة</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>سفر ومناسبات</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>شخصيات ومدونات</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>أخبار وسياسة</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>دليل وستايل</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>أعمال خيرية وأنشطة</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>علوم وتكنولوجيا</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>مسح</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>حفظ الملف</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>الغاء التنزيل: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>خطأ فتح الملف المسجل:  %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>خطأ تسجيل: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>خطأ شبكة: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>ثواني</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>دقائق</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 متبقية</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 من %2 (%3/ثواني) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 من %2 - متوقف</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>بايت</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>كيلوبايت</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>ميجابايت</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 تنزيل</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 تنزيلات </translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>العنوان</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>في وقت سابق اليوم</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 عناصر </translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>Clone Tab</source>
        <translation>استنساخ علامة التبويب</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>واغلاق علامة التبويب</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>اغلاق وعلامات تبويب أخرى</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>تحديث علامة التبويب</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>تحديث كل علامات التبويب</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>New &amp;Tab</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>علامات التبويب التي تم فتحها مؤخرا</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(دون عنوان)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>لا توجد عمليات بحث حديثة</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>عمليات بحث حديثة</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>مسح عمليات البحث الحديثة</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>تنزيل</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>اضافة الى الوثيقة الحالية</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>خطأ تحميل الصفحة: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>فتح في علامة تبويب جديدة</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>نشر البودكاست على يوتيوب</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>العنوان</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>الكلمات الرئيسية</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>فئة</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>اسم مستخدم اليوتوب</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>كلمة سر اليوتوب</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;بالضغط على &apos;تحميل&apos;، تشهدون أنكم تملكون كل حقوق المحتوى أو أنكم تملكون رخصة من مالك الحقوق لنشر المحتوى على اليوتوب، وأنه يخترم شروط استعمال لبيوتوب الموجودة في &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>في خلفية مضيئة</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>في خلفية داكنة</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>معدل الشفافية</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>عرض الخط</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>متوسط</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>قوي</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>دقيق</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>القلم حساس للضغط </translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>حوار</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>البريد الالكتروني</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>الناشر</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">حوار</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">البريد الالكتروني</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">الناشر</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">الوصف</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>تفضيلات</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Default Settings</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>عرض الصفحة على متصفح خارجي</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>الصفحة الرئيسية:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>لوحة مفاتيح افتراضية</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">حجم أزرار لوحة المفاتيح:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>شريط الأدوات</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>متمركز في الأعلى (منصوح به للكمبيوتر اللوحي)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>متمركز في الأسفل (منصوح به اللوحات البيضاء)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>عرض النص أسفل الزر</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>لوح الرسم</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>أفقي</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>عمودي</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>علامة</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>رخص</translation>
    </message>
    <message>
        <source>About</source>
        <translation>حول</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>تحيين البرنامج</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>التحقق من تحيين البرنامج عن الانطلاق</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>شبكة</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>نسخة:</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>عرض محتوى صفحة الويب الداخلية على الشاشة الثانوية أو جهاز العرض</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>عرض متعدد</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>تبديل عرض التحكم ومشاهدة العرض</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>نسق</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>نسق البداية:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>لوحة</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>مستعمل بروكسي:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>المرور:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>الشكر إلى</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">في خلفية داكنة</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">معدل الشفافية</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">في خلفية مضيئة</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>إمساك فلاش</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">اختيار فلاش للامساك به</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>اسم التطبيق</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>إنشاء تطبيق</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
